@@ -344,6 +344,9 @@ class Resource:
         privileged_client=None,
         yaml_file=None,
         delete_timeout=TIMEOUT_4MINUTES,
+        dry_run=None,
+        node_selector=None,
+        node_selector_labels=None,
     ):
         """
         Create a API resource
@@ -385,6 +388,16 @@ class Resource:
         self.teardown = teardown
         self.timeout = timeout
         self.delete_timeout = delete_timeout
+        self.dry_run = dry_run
+        self.node_selector = node_selector
+        self.node_selector_labels = node_selector_labels
+        self.node_selector_spec = self._prepare_node_selector_spec()
+
+    def _prepare_node_selector_spec(self):
+        if self.node_selector:
+            return {f"{self.ApiGroup.KUBERNETES_IO}/hostname": self.node_selector}
+        if self.node_selector_labels:
+            return self.node_selector_labels
 
     @ClassProperty
     def kind(cls):  # noqa: N805
@@ -640,7 +653,7 @@ class Resource:
         LOGGER.info(f"Create {self.kind} {self.name}")
         LOGGER.info(f"Posting {data}")
         LOGGER.debug(f"\n{yaml.dump(data)}")
-        res = self.api.create(body=data, namespace=self.namespace)
+        res = self.api.create(body=data, namespace=self.namespace, dry_run=self.dry_run)
         if wait and res:
             return self.wait()
         return res
@@ -848,6 +861,7 @@ class NamespacedResource(Resource):
         privileged_client=None,
         yaml_file=None,
         delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -857,6 +871,7 @@ class NamespacedResource(Resource):
             privileged_client=privileged_client,
             yaml_file=yaml_file,
             delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.namespace = namespace
         if not (self.name and self.namespace) and not self.yaml_file:
